@@ -51,8 +51,8 @@ build_time_vars = {'ABIFLAGS': '',
                 "'--mandir=/usr/share/man' '--infodir=/usr/share/info' "
                 "'--datadir=/usr/share' '--sysconfdir=/etc' "
                 "'--localstatedir=/var/lib' '--datarootdir=/usr/share' "
-                "'--docdir=/usr/share/doc/python-3.12.8' "
-                "'--htmldir=/usr/share/doc/python-3.12.8/html' "
+                "'--docdir=/usr/share/doc/python-3.12.9' "
+                "'--htmldir=/usr/share/doc/python-3.12.9/html' "
                 "'--libdir=/usr/lib' 'ac_cv_header_stropts_h=no' "
                 "'--enable-shared' '--without-static-libpython' "
                 "'--enable-ipv6' '--infodir=/usr/share/info' "
@@ -72,9 +72,9 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.12',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/var/tmp/portage/dev-lang/python-3.12.8/work/Python-3.12.8/coverage.info',
+ 'COVERAGE_INFO': '/var/tmp/portage/dev-lang/python-3.12.9/work/Python-3.12.9/coverage.info',
  'COVERAGE_LCOV_OPTIONS': '--rc lcov_branch_coverage=1',
- 'COVERAGE_REPORT': '/var/tmp/portage/dev-lang/python-3.12.8/work/Python-3.12.8/lcov-report',
+ 'COVERAGE_REPORT': '/var/tmp/portage/dev-lang/python-3.12.9/work/Python-3.12.9/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--rc lcov_branch_coverage=1 --branch-coverage '
                             '--title "CPython 3.12 LCOV report [commit $(shell '
                             ')]"',
@@ -411,7 +411,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_POSIX_SPAWNP': 1,
  'HAVE_PREAD': 1,
  'HAVE_PREADV': 1,
- 'HAVE_PREADV2': 0,
+ 'HAVE_PREADV2': 1,
  'HAVE_PRLIMIT': 1,
  'HAVE_PROCESS_H': 0,
  'HAVE_PROTOTYPES': 1,
@@ -426,7 +426,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_PTY_H': 1,
  'HAVE_PWRITE': 1,
  'HAVE_PWRITEV': 1,
- 'HAVE_PWRITEV2': 0,
+ 'HAVE_PWRITEV2': 1,
  'HAVE_READLINE_READLINE_H': 0,
  'HAVE_READLINK': 1,
  'HAVE_READLINKAT': 1,
@@ -551,6 +551,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SYS_MODEM_H': 0,
  'HAVE_SYS_NDIR_H': 0,
  'HAVE_SYS_PARAM_H': 1,
+ 'HAVE_SYS_PIDFD_H': 0,
  'HAVE_SYS_POLL_H': 1,
  'HAVE_SYS_RANDOM_H': 1,
  'HAVE_SYS_RESOURCE_H': 1,
@@ -584,7 +585,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_TMPNAM_R': 0,
  'HAVE_TM_ZONE': 1,
  'HAVE_TRUNCATE': 1,
- 'HAVE_TTYNAME': 1,
+ 'HAVE_TTYNAME_R': 1,
  'HAVE_TZNAME': 0,
  'HAVE_UMASK': 1,
  'HAVE_UNAME': 1,
@@ -624,15 +625,15 @@ build_time_vars = {'ABIFLAGS': '',
                    '/usr/include/python3.12',
  'INCLUDEDIR': '/usr/include',
  'INCLUDEPY': '/usr/include/python3.12',
- 'INSTALL': '/var/tmp/portage/._portage_reinstall_.354gqr52/bin/ebuild-helpers/xattr/install '
+ 'INSTALL': '/var/tmp/portage/._portage_reinstall_.4jg0gal1/bin/ebuild-helpers/xattr/install '
             '-c',
- 'INSTALL_DATA': '/var/tmp/portage/._portage_reinstall_.354gqr52/bin/ebuild-helpers/xattr/install '
+ 'INSTALL_DATA': '/var/tmp/portage/._portage_reinstall_.4jg0gal1/bin/ebuild-helpers/xattr/install '
                  '-c -m 644',
- 'INSTALL_PROGRAM': '/var/tmp/portage/._portage_reinstall_.354gqr52/bin/ebuild-helpers/xattr/install '
+ 'INSTALL_PROGRAM': '/var/tmp/portage/._portage_reinstall_.4jg0gal1/bin/ebuild-helpers/xattr/install '
                     '-c',
- 'INSTALL_SCRIPT': '/var/tmp/portage/._portage_reinstall_.354gqr52/bin/ebuild-helpers/xattr/install '
+ 'INSTALL_SCRIPT': '/var/tmp/portage/._portage_reinstall_.4jg0gal1/bin/ebuild-helpers/xattr/install '
                    '-c',
- 'INSTALL_SHARED': '/var/tmp/portage/._portage_reinstall_.354gqr52/bin/ebuild-helpers/xattr/install '
+ 'INSTALL_SHARED': '/var/tmp/portage/._portage_reinstall_.4jg0gal1/bin/ebuild-helpers/xattr/install '
                    '-c -m 755',
  'INSTSONAME': 'libpython3.12.so.1.0',
  'IO_H': 'Modules/_io/_iomodule.h',
@@ -1083,7 +1084,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': '@READELF@',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.12.8/work/Python-3.12.8',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.12.9/work/Python-3.12.9',
  'SCRIPTDIR': '/usr/lib',
  'SCRIPT_2TO3': 'build/scripts-3.12/2to3-3.12',
  'SCRIPT_IDLE': 'build/scripts-3.12/idle3.12',
@@ -1207,10 +1208,10 @@ build_time_vars = {'ABIFLAGS': '',
  'SYS_SELECT_WITH_SYS_TIME': 1,
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.12.8/work/Python-3.12.8 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.12.9/work/Python-3.12.9 '
                './python -E',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.12.8/work/Python-3.12.8 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.12.9/work/Python-3.12.9 '
                './python -E ./Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'idlelib/idle_test \\',
  'TESTTIMEOUT': 1200,
@@ -1240,8 +1241,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/var/tmp/portage/dev-lang/python-3.12.8/work/Python-3.12.8',
- 'abs_srcdir': '/var/tmp/portage/dev-lang/python-3.12.8/work/Python-3.12.8',
+ 'abs_builddir': '/var/tmp/portage/dev-lang/python-3.12.9/work/Python-3.12.9',
+ 'abs_srcdir': '/var/tmp/portage/dev-lang/python-3.12.9/work/Python-3.12.9',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
