@@ -31,13 +31,11 @@ build_time_vars = {'ABIFLAGS': '',
  'CFLAGS_NODIST': '',
  'CODECS_COMMON_HEADERS': './Modules/cjkcodecs/multibytecodec.h '
                           './Modules/cjkcodecs/cjkcodecs.h',
- 'COMPILEALL_OPTS': '-j24',
+ 'COMPILEALL_OPTS': '-j2',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
  'CONFIGURE_CFLAGS': '',
- 'CONFIGURE_CFLAGS_NODIST': '-O3 -pipe -march=ivybridge -mtune=skylake '
-                            '-frecord-gcc-switches -fdiagnostics-color=never '
-                            '-mavx -mavx2 -mfma -fwrapv -std=c11 -Wextra '
+ 'CONFIGURE_CFLAGS_NODIST': '-march=native -O2 -pipe -fwrapv -std=c11 -Wextra '
                             '-Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
                             '-Wstrict-prototypes '
@@ -45,18 +43,16 @@ build_time_vars = {'ABIFLAGS': '',
                             '-fvisibility=hidden',
  'CONFIGURE_CPPFLAGS': '-I/usr/include/ncursesw',
  'CONFIGURE_LDFLAGS': '',
- 'CONFIGURE_LDFLAGS_NODIST': '-v -Wl,-O1 -Wl,--as-needed '
-                             '-Wl,-z,pack-relative-relocs -Wl,-O2 '
-                             '-Wl,--as-needed -Wl,-z,pack-relative-relocs '
-                             '-Wl,-z,relro -Wl,-z,now',
+ 'CONFIGURE_LDFLAGS_NODIST': '-Wl,-O1 -Wl,--as-needed '
+                             '-Wl,-z,pack-relative-relocs',
  'CONFIGURE_LDFLAGS_NOLTO': '',
  'CONFIG_ARGS': "'--prefix=/usr' '--build=x86_64-pc-linux-gnu' "
                 "'--host=x86_64-pc-linux-gnu' '--mandir=/usr/share/man' "
                 "'--infodir=/usr/share/info' '--datadir=/usr/share' "
                 "'--sysconfdir=/etc' '--localstatedir=/var/lib' "
                 "'--datarootdir=/usr/share' "
-                "'--docdir=/usr/share/doc/python-3.12.8_p1' "
-                "'--htmldir=/usr/share/doc/python-3.12.8_p1/html' "
+                "'--docdir=/usr/share/doc/python-3.12.9' "
+                "'--htmldir=/usr/share/doc/python-3.12.9/html' "
                 "'--libdir=/usr/lib64' 'ac_cv_header_stropts_h=no' "
                 "'--enable-shared' '--without-static-libpython' "
                 "'--enable-ipv6' '--infodir=/usr/share/info' "
@@ -76,9 +72,9 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.12',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/var/tmp/portage/dev-lang/python-3.12.8_p1/work/Python-3.12.8/coverage.info',
+ 'COVERAGE_INFO': '/var/tmp/portage/dev-lang/python-3.12.9/work/Python-3.12.9/coverage.info',
  'COVERAGE_LCOV_OPTIONS': '--rc lcov_branch_coverage=1',
- 'COVERAGE_REPORT': '/var/tmp/portage/dev-lang/python-3.12.8_p1/work/Python-3.12.8/lcov-report',
+ 'COVERAGE_REPORT': '/var/tmp/portage/dev-lang/python-3.12.9/work/Python-3.12.9/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--rc lcov_branch_coverage=1 --branch-coverage '
                             '--title "CPython 3.12 LCOV report [commit $(shell '
                             ')]"',
@@ -555,6 +551,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SYS_MODEM_H': 0,
  'HAVE_SYS_NDIR_H': 0,
  'HAVE_SYS_PARAM_H': 1,
+ 'HAVE_SYS_PIDFD_H': 1,
  'HAVE_SYS_POLL_H': 1,
  'HAVE_SYS_RANDOM_H': 1,
  'HAVE_SYS_RESOURCE_H': 1,
@@ -588,7 +585,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_TMPNAM_R': 1,
  'HAVE_TM_ZONE': 1,
  'HAVE_TRUNCATE': 1,
- 'HAVE_TTYNAME': 1,
+ 'HAVE_TTYNAME_R': 1,
  'HAVE_TZNAME': 0,
  'HAVE_UMASK': 1,
  'HAVE_UNAME': 1,
@@ -651,21 +648,17 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBDEST': '/usr/lib/python3.12',
  'LIBDIR': '/usr/lib64',
  'LIBEXPAT_A': 'Modules/expat/libexpat.a',
- 'LIBEXPAT_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O3 -pipe '
-                    '-march=ivybridge -mtune=skylake -frecord-gcc-switches '
-                    '-fdiagnostics-color=never -mavx -mavx2 -mfma -fwrapv '
-                    '-std=c11 -Wextra -Wno-unused-parameter '
-                    '-Wno-missing-field-initializers -Wstrict-prototypes '
-                    '-Werror=implicit-function-declaration '
+ 'LIBEXPAT_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG '
+                    '-march=native -O2 -pipe -fwrapv -std=c11 -Wextra '
+                    '-Wno-unused-parameter -Wno-missing-field-initializers '
+                    '-Wstrict-prototypes -Werror=implicit-function-declaration '
                     '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
                     '-I/usr/include/ncursesw -fPIC -fPIC',
  'LIBEXPAT_HEADERS': '\\',
  'LIBEXPAT_OBJS': '\\',
  'LIBHACL_CFLAGS': '-I./Modules/_hacl/include -D_BSD_SOURCE -D_DEFAULT_SOURCE '
-                   '-fno-strict-overflow -Wsign-compare -DNDEBUG -O3 -pipe '
-                   '-march=ivybridge -mtune=skylake -frecord-gcc-switches '
-                   '-fdiagnostics-color=never -mavx -mavx2 -mfma -fwrapv '
-                   '-std=c11 -Wextra -Wno-unused-parameter '
+                   '-fno-strict-overflow -Wsign-compare -DNDEBUG -march=native '
+                   '-O2 -pipe -fwrapv -std=c11 -Wextra -Wno-unused-parameter '
                    '-Wno-missing-field-initializers -Wstrict-prototypes '
                    '-Werror=implicit-function-declaration -fvisibility=hidden  '
                    '-I./Include/internal -I. -I./Include '
@@ -677,12 +670,10 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBM': '-lm',
  'LIBMPDEC_A': 'Modules/_decimal/libmpdec/libmpdec.a',
  'LIBMPDEC_CFLAGS': '-DCONFIG_64=1 -DANSI=1 -DHAVE_UINT128_T=1 '
-                    '-fno-strict-overflow -Wsign-compare -DNDEBUG -O3 -pipe '
-                    '-march=ivybridge -mtune=skylake -frecord-gcc-switches '
-                    '-fdiagnostics-color=never -mavx -mavx2 -mfma -fwrapv '
-                    '-std=c11 -Wextra -Wno-unused-parameter '
-                    '-Wno-missing-field-initializers -Wstrict-prototypes '
-                    '-Werror=implicit-function-declaration '
+                    '-fno-strict-overflow -Wsign-compare -DNDEBUG '
+                    '-march=native -O2 -pipe -fwrapv -std=c11 -Wextra '
+                    '-Wno-unused-parameter -Wno-missing-field-initializers '
+                    '-Wstrict-prototypes -Werror=implicit-function-declaration '
                     '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
                     '-I/usr/include/ncursesw -fPIC -fPIC',
  'LIBMPDEC_HEADERS': '\\',
@@ -1045,10 +1036,8 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha2,sha3,blake2"',
- 'PY_BUILTIN_MODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O3 '
-                             '-pipe -march=ivybridge -mtune=skylake '
-                             '-frecord-gcc-switches -fdiagnostics-color=never '
-                             '-mavx -mavx2 -mfma -fwrapv -std=c11 -Wextra '
+ 'PY_BUILTIN_MODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG '
+                             '-march=native -O2 -pipe -fwrapv -std=c11 -Wextra '
                              '-Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Wstrict-prototypes '
@@ -1057,41 +1046,31 @@ build_time_vars = {'ABIFLAGS': '',
                              '-I./Include -I/usr/include/ncursesw -fPIC '
                              '-DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG',
- 'PY_CFLAGS_NODIST': '-O3 -pipe -march=ivybridge -mtune=skylake '
-                     '-frecord-gcc-switches -fdiagnostics-color=never -mavx '
-                     '-mavx2 -mfma -fwrapv -std=c11 -Wextra '
+ 'PY_CFLAGS_NODIST': '-march=native -O2 -pipe -fwrapv -std=c11 -Wextra '
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
                      '-Wstrict-prototypes '
                      '-Werror=implicit-function-declaration '
                      '-fvisibility=hidden  -I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
- 'PY_CORE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O3 -pipe '
-                   '-march=ivybridge -mtune=skylake -frecord-gcc-switches '
-                   '-fdiagnostics-color=never -mavx -mavx2 -mfma -fwrapv '
-                   '-std=c11 -Wextra -Wno-unused-parameter '
+ 'PY_CORE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -march=native '
+                   '-O2 -pipe -fwrapv -std=c11 -Wextra -Wno-unused-parameter '
                    '-Wno-missing-field-initializers -Wstrict-prototypes '
                    '-Werror=implicit-function-declaration -fvisibility=hidden  '
                    '-I./Include/internal -I. -I./Include '
                    '-I/usr/include/ncursesw -fPIC -DPy_BUILD_CORE',
- 'PY_CORE_LDFLAGS': '-v -Wl,-O1 -Wl,--as-needed -Wl,-z,pack-relative-relocs '
-                    '-Wl,-O2 -Wl,--as-needed -Wl,-z,pack-relative-relocs '
-                    '-Wl,-z,relro -Wl,-z,now',
+ 'PY_CORE_LDFLAGS': '-Wl,-O1 -Wl,--as-needed -Wl,-z,pack-relative-relocs',
  'PY_CPPFLAGS': '-I. -I./Include -I/usr/include/ncursesw',
  'PY_ENABLE_SHARED': 1,
  'PY_HAVE_PERF_TRAMPOLINE': 1,
  'PY_LDFLAGS': '',
- 'PY_LDFLAGS_NODIST': '-v -Wl,-O1 -Wl,--as-needed -Wl,-z,pack-relative-relocs '
-                      '-Wl,-O2 -Wl,--as-needed -Wl,-z,pack-relative-relocs '
-                      '-Wl,-z,relro -Wl,-z,now',
+ 'PY_LDFLAGS_NODIST': '-Wl,-O1 -Wl,--as-needed -Wl,-z,pack-relative-relocs',
  'PY_LDFLAGS_NOLTO': '',
  'PY_SQLITE_ENABLE_LOAD_EXTENSION': 1,
  'PY_SQLITE_HAVE_SERIALIZE': 1,
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
- 'PY_STDMODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O3 '
-                        '-pipe -march=ivybridge -mtune=skylake '
-                        '-frecord-gcc-switches -fdiagnostics-color=never -mavx '
-                        '-mavx2 -mfma -fwrapv -std=c11 -Wextra '
+ 'PY_STDMODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG '
+                        '-march=native -O2 -pipe -fwrapv -std=c11 -Wextra '
                         '-Wno-unused-parameter -Wno-missing-field-initializers '
                         '-Wstrict-prototypes '
                         '-Werror=implicit-function-declaration '
@@ -1108,7 +1087,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': '@READELF@',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.12.8_p1/work/Python-3.12.8',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.12.9/work/Python-3.12.9',
  'SCRIPTDIR': '/usr/lib',
  'SCRIPT_2TO3': 'build/scripts-3.12/2to3-3.12',
  'SCRIPT_IDLE': 'build/scripts-3.12/idle3.12',
@@ -1232,10 +1211,10 @@ build_time_vars = {'ABIFLAGS': '',
  'SYS_SELECT_WITH_SYS_TIME': 1,
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.12.8_p1/work/Python-3.12.8 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.12.9/work/Python-3.12.9 '
                './python -E',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.12.8_p1/work/Python-3.12.8 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.12.9/work/Python-3.12.9 '
                './python -E ./Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'idlelib/idle_test \\',
  'TESTTIMEOUT': 1200,
@@ -1265,8 +1244,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/var/tmp/portage/dev-lang/python-3.12.8_p1/work/Python-3.12.8',
- 'abs_srcdir': '/var/tmp/portage/dev-lang/python-3.12.8_p1/work/Python-3.12.8',
+ 'abs_builddir': '/var/tmp/portage/dev-lang/python-3.12.9/work/Python-3.12.9',
+ 'abs_srcdir': '/var/tmp/portage/dev-lang/python-3.12.9/work/Python-3.12.9',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
